@@ -25,8 +25,6 @@
 
 #include <ctype.h>
 
-#define P_SIPWITCH_NODE "P-sipwitch-node"
-
 #define SECOND_TIMEOUT  (1000l)
 #define MINUTE_TIMEOUT  (SECOND_TIMEOUT * 60l)
 #define HOUR_TIMEOUT    (MINUTE_TIMEOUT * 60l)
@@ -52,6 +50,20 @@ class thread;
 
 typedef enum {EXTERNAL, LOCAL, PUBLIC, ROUTED, FORWARDED, REDIRECTED} destination_t;
 
+class __LOCAL digests
+{
+public:
+    static void reload(void);
+
+    static const char *get(const char *id);
+
+    static bool set(const char *id, const char *hash);
+
+    static void release(const char *hash);
+
+    static void load(void);
+};
+
 class __LOCAL registry : private service::callback, private mapped_array<MappedRegistry>
 {
 public:
@@ -202,7 +214,7 @@ public:
     static pattern *getRouting(unsigned trs, const char *id);
     static void detach(mapped *m);
     static bool remove(const char *id);
-    static void cleanup(time_t period);
+    static unsigned cleanup(time_t period);
 };
 
 class __LOCAL stack : public service::callback, private mapped_array<MappedCall>, public OrderedIndex
@@ -606,6 +618,7 @@ private:
     thread(voip::context_t ctx, const char *tag);
 
     static void wait(unsigned count);
+    static const char *eid(eXosip_event_type ev);
 
     void send_reply(int error);
     void expiration(void);
