@@ -226,7 +226,12 @@ void stack::background::run(void)
     shell::log(DEBUG1, "starting background thread");
     timeout_t timeout, current;
     Timer expiration = interval;
+    time_t then = 0, now;
     stack::call *next;
+    time_t period = 10;
+
+    time(&then);
+    then /= period;
 
     for(;;) {
         Conditional::lock();
@@ -264,6 +269,16 @@ void stack::background::run(void)
             signalled = false;
             Conditional::unlock();
         }
+        time(&now);
+        now /= period;
+        if(now > then) {
+            then = now;
+            unsigned released = registry::cleanup(period);
+            if(released)
+                shell::log(shell::DEBUG1, "registry cleanup; %d expired", released);
+            else
+                shell::log(shell::DEBUG1, "registry cleanup; no entries expired");
+        }
         messages::automatic();
     }
 }
@@ -1305,11 +1320,11 @@ int stack::inviteRemote(stack::session *s, const char *uri_target, const char *d
 
     // default if no target route lookup...
 
+    Socket::address resolve;
     if(!target) {
         if(!port)
             port = 5060;
 
-        Socket::address resolve;
         resolve.set(route, port);
         target = resolve.getAddr();
     }
